/* Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * 
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Named Anchors.
 * 
 * The Initial Developer of the Original Code is Jeroen Peters. 
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 * 
 * Contributor(s):
 *   Jeroen Peters <jpeters@coldmail.nl>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

// one nsITreeView for each tree in the window
const COPYCOL_ANCHOR_ADDRESS = 1;
var anchorView = new pageInfoTreeView(["anchor-name","anchor-address"], COPYCOL_ANCHOR_ADDRESS);
var anchorDoc;

function makeNamedAnchorsTab() 
{
  var anchorTree = document.getElementById("anchortree");
  anchorTree.treeBoxObject.view = anchorView;

  // Refresh anchorDoc as an extension can load a new document and reload pageInfo
  anchorDoc = "gDocument" in window ? gDocument : theDocument;

  var re = new RegExp( "("+ anchorDoc.location.hash + "$)" );
  var docHref = anchorDoc.location.href.replace(re, "");

  var namedAnchors = getNamedAnchors();
  for (var i=0; i<namedAnchors.length; i++)
  {
    anchorName = namedAnchors[i][0];
    anchorAddress = docHref + "#" + anchorName;
    anchorView.addRow([ anchorName, anchorAddress, namedAnchors[i][1] ]);
  }
}


/*
 * Returns an array with all A elements with a name attribute and 
 * the A elements with an id attribute and *no* href attribute.
 */
function getNamedAnchors()
{
  var result = new Array();
  var content = "";
  var maxContentLength = 250;
  var elems = anchorDoc.getElementsByTagName("a");
  
  for (var i=0; i<elems.length; i++)
  {
    // Consider anchors with a name attribute and...
    if (elems[i].name != "") 
    {
      //content = getElementContent(elems[i].firstChild);
      content = left( stripHTML(elems[i].innerHTML), maxContentLength);
      result.push( new Array(elems[i].name, content) );
    }
    // ...anchors with an id, but without a href as named anchors
    else if (elems[i].id != "" && elems[i].href == "")
    {
      //content = getElementContent(elems[i].firstChild);
      content = left( stripHTML(elems[i].innerHTML), maxContentLength);
      result.push( new Array(elems[i].id, content) );
    }
  }

  return result;
}


/*
 * Strip all HTML tags and new lines (\n) from a string
 */ 
function stripHTML(htmlString)
{
  var result = htmlString.replace(/<[^>]+>|\n/ig,"");

  return result;
}


/*
 * Return maxLength characters from the string S. If the length of S larger than 
 * maxLength, the string is appended with a postfix string. The length of the result 
 * string and the posfix string equeals maxLength.
 */
function left(S, maxLength)
{
  var result;
  var postfix = "...";

  if (S.length > maxLength)
  {
    result = S.substr(0, maxLength-postfix.length) + postfix;
  }
  else
    result = S;
    
  return result;
}
